=======================
Factorial Survey Design
=======================


.. image:: https://img.shields.io/pypi/v/fsdesign.svg
        :target: https://pypi.python.org/pypi/fsdesign

.. image:: https://img.shields.io/travis/bertucho/fsdesign.svg
        :target: https://travis-ci.org/bertucho/fsdesign

.. image:: https://readthedocs.org/projects/fsdesign/badge/?version=latest
        :target: https://fsdesign.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python package for Factorial Survey Design


* Free software: MIT license
* Documentation: https://fsdesign.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
